@@ -18,8 +18,14 @@ KeelAlgorithm <- R6::R6Class("KeelAlgorithm",
       rJava::.jinit()
       jv <- rJava::.jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
       if(substr(jv, 1L, 1L) == "1") {
-        jvn <- as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
-        if(jvn < 1.8) stop("Java 8 is needed for this package but not available")
+        jvn <- as.numeric(paste0(strsplit(jv, "[+.]")[[1L]][1:2], collapse = "."))
+        #Check java version under 8
+        if(jvn < 1.8 || is.na(jvn)){
+          #If it fails here, it could be java version 10, so we check it
+          if(substr(paste0(strsplit(jv, "[.+]")[[1L]][1:2], collapse = "."), 1, 2) != "10"){
+            stop("Java 8 is needed for this package but not available")
+          }
+        } 
       }
 
       rJava::.jinit()
